@@ -17,9 +17,9 @@ Get_conffiles ()
 		for FILE in ${@}
 		do
 			FILES="${FILES} ${FILE} ${FILE}.${LB_ARCHITECTURE} ${FILE}.${DISTRIBUTION}"
-			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lh_||')"
-			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lh_||').${ARCHITECTURE}"
-			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lh_||').${DISTRIBUTION}"
+			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lb_||')"
+			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lb_||').${ARCHITECTURE}"
+			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lb_||').${DISTRIBUTION}"
 		done
 	fi
 
